#include <../../Common/LED.cpp>
#include <../../Common/Variables.cpp>
#include <Arduino.h>
#include <ESP8266WiFi.h>
#include <espnow.h>

#define TIMEOUT_DURATION 30000 // 30 seconds

void messageCallback(int value);
LED _led(D1, FADE_IN_DURATION, FADE_OUT_DURATION);
unsigned long _lastMessageTime;
bool _timedOut = false;

void resetTimeout(){
	_lastMessageTime = millis();
	_timedOut = false;
}

void messageCallback(int value){
	Serial.print("Message: ");
	Serial.println(value);

	value ? _led.on() : _led.off();

	resetTimeout();
}

void OnDataRecv(uint8_t *mac, uint8_t *incomingData, uint8_t len) {
	int value;
	memcpy(&value, incomingData, sizeof(value));
	Serial.println(value);
	messageCallback(value);
}

void timeout(){
	if (!_timedOut && millis() >= _lastMessageTime + TIMEOUT_DURATION){
		Serial.println("No message for 30 seconds.");
		_led.off();
		_timedOut = true;
	}
}

void setupReceiver() {
	Serial.print("ESP8266 Board MAC Address:  ");
	Serial.println(WiFi.macAddress());

	WiFi.mode(WIFI_STA);

	if (esp_now_init() != 0) {
		Serial.println("Error initialising ESP-NOW");
		return;
	}

	esp_now_set_self_role(ESP_NOW_ROLE_SLAVE);
	esp_now_register_recv_cb(OnDataRecv);
}

void setup(){
	Serial.begin(115200);
	Serial.println("Starting...");
	setupReceiver();
	Serial.println("Started");
	_led.off();
	_lastMessageTime = millis();
}

void loop(){
	_led.loop();
	timeout();
	delay(10);
}