#include <Arduino.h>

class Button {
	const unsigned int _debounceDelay = 50;

	unsigned int _pin;
	unsigned long _lastDebounce;
	bool _prevButtonValue, _currentValue;
	void (*_pressCallback)(void);
	void (*_releaseCallback)(void);

public:
	Button(unsigned int pin, void (*pressCallback)(void), void (*releaseCallback)(void)) {
		_pin = pin;
		_pressCallback = pressCallback;
		_releaseCallback = releaseCallback;
		pinMode(pin, INPUT);
	}

	void loop() {
		bool reading = digitalRead(_pin);

		if (_prevButtonValue != reading) {
			_lastDebounce = millis();
		}

		if (millis() - _lastDebounce > _debounceDelay && reading != _currentValue){
			_currentValue = reading;
			if (_currentValue)
				_pressCallback();
			else
				_releaseCallback();
		}

		_prevButtonValue = reading;
	}
};