#include <Arduino.h>
#include <Motion.cpp>
#include <Transmitter.cpp>
#include <Timer.cpp>
#include <../../Common/LED.cpp>
#include <../../Common/Variables.cpp>

void turnOn();
void turnOff();
void resend();
Motion _motion(D7, ON_DURATION, &turnOn, &turnOff);
unsigned int _signalValue;
Transmitter _transmitter;
Timer _timer(1000, &resend);
LED _led(D1, FADE_IN_DURATION, FADE_OUT_DURATION);

void sendSignal(int value){
	_signalValue=value;
	Serial.print("Transmitting: ");
	Serial.println(value);
	_transmitter.send(value);
	Serial.println("Transmitted");
}

void turnOn(){
	sendSignal(1);
	_led.on();
}

void turnOff(){
	sendSignal(0);
	_led.off();
}

void resend(){
	sendSignal(_signalValue);
}

void setup() {
	Serial.begin(115200);
	Serial.println("Starting");
	_transmitter.setup();
	_motion.setup();
	Serial.println("Started");
}

void loop() {
	_motion.loop();
	_timer.loop();
	_led.loop();
	delay(10);
}